==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/BehaviorRuleSettingsHistoryBased.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * BehaviorRuleSettingsHistoryBased
 */
@JsonPropertyOrder({ BehaviorRuleSettingsHistoryBased.JSON_PROPERTY_MAX_EVENTS_USED_FOR_EVALUATION,
        BehaviorRuleSettingsHistoryBased.JSON_PROPERTY_MIN_EVENTS_NEEDED_FOR_EVALUATION })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class BehaviorRuleSettingsHistoryBased implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_MAX_EVENTS_USED_FOR_EVALUATION = "maxEventsUsedForEvaluation";
    private Integer maxEventsUsedForEvaluation = 20;

    public static final String JSON_PROPERTY_MIN_EVENTS_NEEDED_FOR_EVALUATION = "minEventsNeededForEvaluation";
    private Integer minEventsNeededForEvaluation = 0;

    public BehaviorRuleSettingsHistoryBased() {
    }

    public BehaviorRuleSettingsHistoryBased maxEventsUsedForEvaluation(Integer maxEventsUsedForEvaluation) {

        this.maxEventsUsedForEvaluation = maxEventsUsedForEvaluation;
        return this;
    }

    /**
     * Get maxEventsUsedForEvaluation minimum: 1 maximum: 100
     *
     * @return maxEventsUsedForEvaluation
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_MAX_EVENTS_USED_FOR_EVALUATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Integer getMaxEventsUsedForEvaluation() {
        return maxEventsUsedForEvaluation;
    }

    @JsonProperty(JSON_PROPERTY_MAX_EVENTS_USED_FOR_EVALUATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setMaxEventsUsedForEvaluation(Integer maxEventsUsedForEvaluation) {
        this.maxEventsUsedForEvaluation = maxEventsUsedForEvaluation;
    }

    public BehaviorRuleSettingsHistoryBased minEventsNeededForEvaluation(Integer minEventsNeededForEvaluation) {

        this.minEventsNeededForEvaluation = minEventsNeededForEvaluation;
        return this;
    }

    /**
     * Get minEventsNeededForEvaluation minimum: 0 maximum: 10
     *
     * @return minEventsNeededForEvaluation
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_MIN_EVENTS_NEEDED_FOR_EVALUATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Integer getMinEventsNeededForEvaluation() {
        return minEventsNeededForEvaluation;
    }

    @JsonProperty(JSON_PROPERTY_MIN_EVENTS_NEEDED_FOR_EVALUATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setMinEventsNeededForEvaluation(Integer minEventsNeededForEvaluation) {
        this.minEventsNeededForEvaluation = minEventsNeededForEvaluation;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        BehaviorRuleSettingsHistoryBased behaviorRuleSettingsHistoryBased = (BehaviorRuleSettingsHistoryBased) o;
        return Objects.equals(this.maxEventsUsedForEvaluation,
                behaviorRuleSettingsHistoryBased.maxEventsUsedForEvaluation)
                && Objects.equals(this.minEventsNeededForEvaluation,
                        behaviorRuleSettingsHistoryBased.minEventsNeededForEvaluation);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(maxEventsUsedForEvaluation, minEventsNeededForEvaluation);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class BehaviorRuleSettingsHistoryBased {\n");
        sb.append("    maxEventsUsedForEvaluation: ").append(toIndentedString(maxEventsUsedForEvaluation)).append("\n");
        sb.append("    minEventsNeededForEvaluation: ").append(toIndentedString(minEventsNeededForEvaluation))
                .append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/BehaviorRuleSettingsHistoryBased.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * BehaviorRuleSettingsHistoryBased
 */
@JsonPropertyOrder({ BehaviorRuleSettingsHistoryBased.JSON_PROPERTY_MAX_EVENTS_USED_FOR_EVALUATION,
        BehaviorRuleSettingsHistoryBased.JSON_PROPERTY_MIN_EVENTS_NEEDED_FOR_EVALUATION })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class BehaviorRuleSettingsHistoryBased implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_MAX_EVENTS_USED_FOR_EVALUATION = "maxEventsUsedForEvaluation";
    private Integer maxEventsUsedForEvaluation = 20;

    public static final String JSON_PROPERTY_MIN_EVENTS_NEEDED_FOR_EVALUATION = "minEventsNeededForEvaluation";
    private Integer minEventsNeededForEvaluation = 0;

    public BehaviorRuleSettingsHistoryBased() {
    }

    public BehaviorRuleSettingsHistoryBased maxEventsUsedForEvaluation(Integer maxEventsUsedForEvaluation) {

        this.maxEventsUsedForEvaluation = maxEventsUsedForEvaluation;
        return this;
    }

    /**
     * Get maxEventsUsedForEvaluation minimum: 1 maximum: 100
     *
     * @return maxEventsUsedForEvaluation
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_MAX_EVENTS_USED_FOR_EVALUATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Integer getMaxEventsUsedForEvaluation() {
        return maxEventsUsedForEvaluation;
    }

    @JsonProperty(JSON_PROPERTY_MAX_EVENTS_USED_FOR_EVALUATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setMaxEventsUsedForEvaluation(Integer maxEventsUsedForEvaluation) {
        this.maxEventsUsedForEvaluation = maxEventsUsedForEvaluation;
    }

    public BehaviorRuleSettingsHistoryBased minEventsNeededForEvaluation(Integer minEventsNeededForEvaluation) {

        this.minEventsNeededForEvaluation = minEventsNeededForEvaluation;
        return this;
    }

    /**
     * Get minEventsNeededForEvaluation minimum: 0 maximum: 10
     *
     * @return minEventsNeededForEvaluation
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_MIN_EVENTS_NEEDED_FOR_EVALUATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Integer getMinEventsNeededForEvaluation() {
        return minEventsNeededForEvaluation;
    }

    @JsonProperty(JSON_PROPERTY_MIN_EVENTS_NEEDED_FOR_EVALUATION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setMinEventsNeededForEvaluation(Integer minEventsNeededForEvaluation) {
        this.minEventsNeededForEvaluation = minEventsNeededForEvaluation;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        BehaviorRuleSettingsHistoryBased behaviorRuleSettingsHistoryBased = (BehaviorRuleSettingsHistoryBased) o;
        return Objects.equals(this.maxEventsUsedForEvaluation,
                behaviorRuleSettingsHistoryBased.maxEventsUsedForEvaluation)
                && Objects.equals(this.minEventsNeededForEvaluation,
                        behaviorRuleSettingsHistoryBased.minEventsNeededForEvaluation);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(maxEventsUsedForEvaluation, minEventsNeededForEvaluation);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class BehaviorRuleSettingsHistoryBased {\n");
        sb.append("    maxEventsUsedForEvaluation: ").append(toIndentedString(maxEventsUsedForEvaluation)).append("\n");
        sb.append("    minEventsNeededForEvaluation: ").append(toIndentedString(minEventsNeededForEvaluation))
                .append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
